@@ -33,6 +33,14 @@ class PasswordChangeSerializer(serializers.Serializer):
     password = serializers.CharField(max_length=128)
 
 
+class EmailChangeSerializer(serializers.Serializer):
+    email = serializers.EmailField(max_length=255)
+
+
+class EmailChangeVerifySerializer(serializers.Serializer):
+    email = serializers.EmailField(max_length=255)
+
+
 class UserSerializer(serializers.ModelSerializer):
     class Meta:
         model = get_user_model()
