@@ -62,6 +62,8 @@ class Authemail(API):
         'password_reset': '/password/reset/',
         'password_reset_verify': '/password/reset/verify/',
         'password_reset_verified': '/password/reset/verified/',
+        'email_change': '/email/change/',
+        'email_change_verify': '/email/change/verify/',
         'password_change': '/password/change/',
         'users_me': '/users/me/',
     }
@@ -143,6 +145,26 @@ class Authemail(API):
         self._set_attrs_to_values(response)
         return response
 
+    def email_change(self, **kwargs):
+        path = self._get_path('email_change')
+
+        payload = {
+            'email': kwargs.pop('email'),
+        }
+
+        response = self._POST(path, kwargs, payload)
+
+        self._set_attrs_to_values(response)
+        return response
+
+    def email_change_verify(self, **kwargs):
+        path = self._get_path('email_change_verify')
+
+        response = self._GET(path, kwargs)
+
+        self._set_attrs_to_values(response)
+        return response
+
     def password_change(self, **kwargs):
         path = self._get_path('password_change')
 
